pub struct CmdArgs {
pub config: Option<Vec<PathBuf>>,
pub input: Vec<PathBuf>,
pub workspace: Vec<PathBuf>,
pub exclude_pattern: Option<Vec<String>>,
pub include_pattern: Option<Vec<String>>,
pub output_format: Format,
pub format: Option<Format>,
pub output: OutputDestination,
pub override_template: Option<PathBuf>,
pub site_name: Option<String>,
pub mixin: Option<PathBuf>,
pub verbose: bool,
}Fields
config: Option<Vec<PathBuf>>Configuration file paths. If not provided, both “.emmyrc.json” and “.luarc.json” will be searched in the workspace directory
input: Vec<PathBuf>Deprecated, use [WORKSPACE] instead
workspace: Vec<PathBuf>Path to the workspace directory
exclude_pattern: Option<Vec<String>>Comma separated list of exclude patterns Patterns must follow glob syntax Exclude patterns take precedence over include patterns
include_pattern: Option<Vec<String>>Comma separated list of include patterns Patterns must follow glob syntax
output_format: FormatSpecify output format
format: Option<Format>Deprecated, use –output-format instead
output: OutputDestinationSpecify output destination (can be stdout when output_format is json)
override_template: Option<PathBuf>The path of the override template
site_name: Option<String>mixin: Option<PathBuf>A directory whose contents are merged with the generated Markdown files. For example, to override docs/index.md, create a folder called “docs” in your mixin folder and create a file called “index.md” inside it.
verbose: boolVerbose output